
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.4',
    'branch_nick': 'patch-0-Release__1_21_4_patch_release',
    'revision_id': 'cf7b335ec4ae3eb41dd1db245df65ccffd7bf21e',
    'revno': 9055
}
